==> moniwiki-1.0.tgz: moniwiki/wikismiley.php <==
<?php
# $Id: wikismiley.php,v 1.3 2003/08/09 16:48:26 wkpark Exp wkpark $
$smileys=array(
    "X-("=> array(16, 16, 0, "smile/x-(.gif"),
    ":D"=>  array(16, 16, 0, "smile/8-D.gif"),
    "&lt;:("=> array(15, 15, 0, "frown.gif"),
    ":o"=>  array(16, 16, 0, "smile/8-O.gif"),
    ":("=>  array(16, 16, 0, "smile/8-(.gif"),
    ":)"=>  array(16, 16, 0, "smile/8).gif"),
    ":-)"=> array(16, 16, 0, "smile/8-).gif"),
    "B)"=>  array(16, 16, 0, "smile/B).gif"),
    ":))"=> array(16, 16, 0, "smile/8-)).gif"),
    ";)"=>  array(16, 16, 0, "smile/;-).gif"),
    ";|"=>  array(16, 16, 0, "smile/;-l.gif"),
    ":I"=>  array(16, 16, 0, "smile/8-I.gif"),
    ":|"=>  array(16, 16, 0, "smile/8-l.gif"),
    "|-|"=> array(16, 16, 0, "smile/l-l.gif"),
    "|-I"=> array(16, 16, 0, "smile/l-I.gif"),
    "/!\\"=>array(16, 16, 0, "alert.gif"),
    "\\?/"=>array(16, 16, 0, "icon-question.png"),
    "&lt;!>"=> array(15, 15, 0, "attention.gif"),
    "(!)"=> array(15, 15, 0, "idea.gif"),

#    ":&"=>  array(16, 16, 0, "smile/8-%26.gif"),
    ":-X"=> array(16, 16, 0, "smile/8-x.gif"),
    ":-@"=> array(16, 16, 0, "smile/8-@.gif"),
    ":p"=> array(16, 16, 0, "smile/8-p.gif"),
#    ":^)"=> array(16, 16, 0, "smile/8^).gif"),
#    ":_)"=> array(16, 16, 0, "smile/8).gif"),
#    ":v)"=> array(16, 16, 0, "smile/8).gif"),
#    ":*)"=> array(16, 16, 0, "smile/8star).gif"),
    "$-)"=> array(16, 16, 0, "smile/%24-).gif"),
    ":-$"=> array(16, 16, 0, "smile/8-%24.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
    ":-?"=> array(16, 16, 0, "smile/8-question.gif"),
#    ":\\"=> array(16, 16, 0, "smile/8-ll.gif"),
    ">:>"=> array(16, 16, 0, "smile/v8v.gif"),
    "%-)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%-6"=> array(16, 16, 0, "smile/%25-6.gif"),
#    "%-9"=> array(16, 16, 0, "smile/%25-9.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
#    "B-)"=> array(16, 16, 0, "smile/B-).gif"),
#    ":'-)"=> array(16, 16, 0, "smile/8%27-).gif"),
#    ":'-("=>array(16, 16, 0, "smile/8%27-(.gif"),
#    ":-S"=>array(16, 16, 0, "smile/8-S.gif"),
#    ":-Q"=>array(16, 16, 0, "smile/8-Q.gif"),
    ":->"=>array(16, 16, 0, "smile/8-v.gif"),
#    ":-]"=>array(16, 16, 0, "smile/8-].gif"),
#    "[:-)"=>array(16, 16, 0, "smile/[8-).gif"),
#    ":-["=>array(16, 16, 0, "smile/8-[.gif"),
#    ":-}"=>array(16, 16, 0, "smile/8-}.gif"),
#    "[:]"=>array(16, 16, 0, "smile/[8].gif"),
#    ":^)"=>array(16, 16, 0, "smile/8^).gif"),
#    ":v)"=>array(16, 16, 0, "smile/8).gif"),
    "@)"=>array(16, 16, 0, "smile/@-).gif"),
#    "|)"=>array(16, 16, 0, "smile/l-l.gif"),
#    ":-|"=>array(16, 16, 0, "smile/8-l.gif"),
    ";))"=>array(16, 16, 0, "smile/8-)).gif"),
    "%-^"=>array(16, 16, 0, "smile/%25-^.gif"),
#    "(:)-)"=>array(16, 16, 0, "smile/(8)-).gif"),
#    ",-)"=>array(16, 16, 0, "smile/,-).gif"),
    "-_-"=>array(16, 16, 0, "smile/--.gif"),
    ";;"=>array(7, 16, 0, "smile/;;.gif"),
    "^^"=>array(16, 16, 0, "smile/^^.gif"),
#    "^8l"=>array(16, 16, 0, "smile/^8l.gif"),
#    "~8)"=>array(16, 16, 0, "smile/~8).gif"),
#    "=:-)"=>array(16, 16, 0, "smile/=8-).gif"),
#    "=:-O"=>array(16, 16, 0, "smile/=8O.gif"),
#    "=8-O"=>array(16, 16, 0, "smile/=88O.gif"),
#    ":v"=>array(16, 16, 0, "smile/8v.gif"),
#    ":-{}"=>array(16, 16, 0, "smile/8-{}.gif"),
    ":-9"=>array(16, 16, 0, "smile/8-9.gif"),
#    ":-||"=>array(16, 16, 0, "smile/8-lll.gif"),
#    ":-*"=>array(16, 16, 0, "smile/8-star.gif"),
#    ":-T"=>array(16, 16, 0, "smile/8-T.gif"),
#    ":->"=>array(16, 16, 0, "smile/8-v.gif"),
#    "8>D"=>array(16, 16, 0, "smile/heart-D.gif"),
#    "%]["=>array(12, 16, 0, "smile/beer_r.gif"),
#    "][%"=>array(12, 16, 0, "smile/beer_l.gif"),

    # version 1.0
    "(./)"=>array(14, 16, 0, "checkmark.gif"),
    "{OK}"=>array(12, 16, 0, "smile/thumb-up.gif"),
    "{NO}"=>array(12, 16, 0, "smile/thumb-down.gif"),
    "{X}"=>array(16, 16, 0, "icon-error.gif"),
    "{i}"=>array(16, 16, 0, "icon-info.gif"),
    "{1}"=>array(15, 13, 0, "prio1.gif"),
    "{2}"=>array(15, 13, 0, "prio2.gif"),
    "{3}"=>array(15, 13, 0, "prio3.gif"),
);

?>

==> moniwiki-1.0.2.tgz: moniwiki/wikismiley.php <==
<?php
# $Id: wikismiley.php,v 1.5 2003/08/17 13:47:42 wkpark Exp $
$smileys=array(
    "X-("=> array(16, 16, 0, "smile/x-(.gif"),
    ":D"=>  array(16, 16, 0, "smile/8-D.gif"),
    "&lt;:("=> array(15, 15, 0, "frown.gif"),
    ":o"=>  array(16, 16, 0, "smile/8-O.gif"),
    ":("=>  array(16, 16, 0, "smile/8-(.gif"),
    ":)"=>  array(16, 16, 0, "smile/8).gif"),
    ":-)"=> array(16, 16, 0, "smile/8-).gif"),
    "B)"=>  array(16, 16, 0, "smile/B-).gif"),
    ":))"=> array(16, 16, 0, "smile/8-)).gif"),
    ";)"=>  array(16, 16, 0, "smile/;-).gif"),
    ";|"=>  array(16, 16, 0, "smile/;-l.gif"),
    ":I"=>  array(16, 16, 0, "smile/8-I.gif"),
    ":|"=>  array(16, 16, 0, "smile/8-l.gif"),
    "|-|"=> array(16, 16, 0, "smile/l-l.gif"),
    "|-I"=> array(16, 16, 0, "smile/l-I.gif"),
    "/!\\"=>array(16, 16, 0, "alert.gif"),
    "\\?/"=>array(16, 16, 0, "icon-question.png"),
    "&lt;!>"=> array(15, 15, 0, "attention.gif"),
    "(!)"=> array(15, 15, 0, "idea.gif"),

#    ":&"=>  array(16, 16, 0, "smile/8-%26.gif"),
    ":-X"=> array(16, 16, 0, "smile/8-x.gif"),
    ":-@"=> array(16, 16, 0, "smile/8-@.gif"),
    ":p"=> array(16, 16, 0, "smile/8-p.gif"),
    ":^)"=> array(16, 16, 0, "smile/8^).gif"),
    ":_)"=> array(16, 16, 0, "smile/8_).gif"),
#    ":v)"=> array(16, 16, 0, "smile/8v).gif"),
    ":*)"=> array(16, 16, 0, "smile/8star).gif"),
    "$-)"=> array(16, 16, 0, "smile/%24-).gif"),
    ":-$"=> array(16, 16, 0, "smile/8-%24.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
    ":-?"=> array(16, 16, 0, "smile/8-question.gif"),
#    ":\\"=> array(16, 16, 0, "smile/8-ll.gif"),
    ">:>"=> array(16, 16, 0, "smile/v8v.gif"),
    "%-)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%-6"=> array(16, 16, 0, "smile/%25-6.gif"),
#    "%-9"=> array(16, 16, 0, "smile/%25-9.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
    "B-)"=> array(16, 16, 0, "smile/B-).gif"),
#    ":'-)"=> array(16, 16, 0, "smile/8%27-).gif"),
#    ":'-("=>array(16, 16, 0, "smile/8%27-(.gif"),
    ":-S"=>array(16, 16, 0, "smile/8-S.gif"),
#    ":-Q"=>array(16, 16, 0, "smile/8-Q.gif"),
    ":->"=>array(16, 16, 0, "smile/8-v.gif"),
#    ":-]"=>array(16, 16, 0, "smile/8-].gif"),
#    "[:-)"=>array(16, 16, 0, "smile/[8-).gif"),
#    ":-["=>array(16, 16, 0, "smile/8-[.gif"),
#    ":-}"=>array(16, 16, 0, "smile/8-}.gif"),
#    "[:]"=>array(16, 16, 0, "smile/[8].gif"),
#    ":^)"=>array(16, 16, 0, "smile/8^).gif"),
#    ":v)"=>array(16, 16, 0, "smile/8).gif"),
    "@)"=>array(16, 16, 0, "smile/@-).gif"),
    "|)"=>array(16, 16, 0, "smile/l-l.gif"),
#    ":-|"=>array(16, 16, 0, "smile/8-l.gif"),
    "%-^"=>array(16, 16, 0, "smile/%25-^.gif"),
#    "(:)-)"=>array(16, 16, 0, "smile/(8)-).gif"),
#    ",-)"=>array(16, 16, 0, "smile/,-).gif"),
    "-_-"=>array(16, 16, 0, "smile/--.gif"),
    ";;"=>array(7, 16, 0, "smile/;;.gif"),
    "^^"=>array(16, 16, 0, "smile/^^.gif"),
#    "^8l"=>array(16, 16, 0, "smile/^8l.gif"),
#    "~8)"=>array(16, 16, 0, "smile/~8).gif"),
#    "=:-)"=>array(16, 16, 0, "smile/=8-).gif"),
#    "=:-O"=>array(16, 16, 0, "smile/=8O.gif"),
#    "=8-O"=>array(16, 16, 0, "smile/=88O.gif"),
#    ":v"=>array(16, 16, 0, "smile/8v.gif"),
#    ":-{}"=>array(16, 16, 0, "smile/8-{}.gif"),
    ":-9"=>array(16, 16, 0, "smile/8-9.gif"),
#    ":-||"=>array(16, 16, 0, "smile/8-lll.gif"),
#    ":-*"=>array(16, 16, 0, "smile/8-star.gif"),
#    ":-T"=>array(16, 16, 0, "smile/8-T.gif"),
#    "8>D"=>array(16, 16, 0, "smile/heart-D.gif"),
#    "%]["=>array(12, 16, 0, "smile/beer_r.gif"),
#    "][%"=>array(12, 16, 0, "smile/beer_l.gif"),

    # version 1.0
    "(./)"=>array(14, 16, 0, "checkmark.gif"),
    "{OK}"=>array(12, 16, 0, "smile/thumb-up.gif"),
    "{NO}"=>array(12, 16, 0, "smile/thumb-down.gif"),
    "{X}"=>array(16, 16, 0, "icon-error.gif"),
    "{i}"=>array(16, 16, 0, "icon-info.gif"),
    "{1}"=>array(15, 13, 0, "prio1.gif"),
    "{2}"=>array(15, 13, 0, "prio2.gif"),
    "{3}"=>array(15, 13, 0, "prio3.gif"),
);

?>
